@@ -105,6 +105,7 @@ COLOURS_BY_NAME = {
     "bitter lemon": 0xCAE00D,
     "bittersweet": 0xFE6F5E,
     "bittersweet shimmer": 0xBF4F51,
+    "black": 0x1,
     "black bean": 0x3D0C02,
     "black coral": 0x54626F,
     "black leather jacket": 0x253529,
@@ -837,7 +838,7 @@ COLOURS_BY_NAME = {
     "pine green": 0x01796F,
     "pine tree": 0x2A2F23,
     "pineapple": 0x563C0D,
-    "pink": 0xFFC0CB,
+    "pink": 0xDB0072,
     "pink (pantone)": 0xD74894,
     "pink diamond (ace hardware color)": 0xF6D6DE,
     "pink diamond (independent retailers colors)": 0xF0D3DC,
@@ -1172,6 +1173,7 @@ COLOURS_BY_NAME = {
     "waterspout": 0xA4F4F9,
     "wenge": 0x645452,
     "wheat": 0xF5DEB3,
+    "white": 0xFFFFFF,
     "white chocolate": 0xEDE6D6,
     "white coffee": 0xE6E0D4,
     "wild orchid": 0xD470A2,
