@@ -17,8 +17,8 @@ from discord.iterators import HistoryIterator
 from discord.ext import commands
 import upgradechat
 
-from .custom_context import Context
-from .database import DatabaseConnection
+from .custom_context import Context, SlashContext
+from .database import DatabaseWrapper
 from .redis import RedisConnection
 from .statsd import StatsdConnection
 from .analytics_log_handler import AnalyticsLogHandler, AnalyticsClientSession
@@ -156,6 +156,15 @@ class MinimalBot(commands.AutoShardedBot):
 
         return await super().get_context(message, cls=cls or Context)
 
+    async def get_slash_context(self, interaction, *, cls=None) -> SlashContext:
+        """
+        Create a new context object using the utils' Context.
+
+        :meta private:
+        """
+
+        return await super().get_slash_context(interaction, cls=cls or SlashContext)
+
     def get_context_message(self, channel, content, embed, *args, **kwargs):
         """
         A small base class for us to inherit from so that I don't need to change my
@@ -177,7 +186,7 @@ class Bot(MinimalBot):
         config (dict): The :class:`config<BotConfig>` for the bot.
         session (aiohttp.ClientSession): A session instance that you can use to make web requests.
         application_id (int): The ID of this bot application.
-        database (DatabaseConnection): The database connector, as connected using the data
+        database (DatabaseWrapper): The database connector, as connected using the data
             from your :class:`config file<BotConfig.database>`.
         redis (RedisConnection): The redis connector, as connected using the data from your
             :class:`config file<BotConfig.redis>`.
@@ -255,7 +264,7 @@ class Bot(MinimalBot):
         )
 
         # Allow database connections like this
-        self.database: DatabaseConnection = DatabaseConnection
+        self.database: DatabaseWrapper = DatabaseWrapper
 
         # Allow redis connections like this
         self.redis: RedisConnection = RedisConnection
@@ -314,7 +323,8 @@ class Bot(MinimalBot):
         # Get default guild settings
         default_guild_settings = await db("SELECT * FROM guild_settings WHERE guild_id=0")
         if not default_guild_settings:
-            default_guild_settings = await db("INSERT INTO guild_settings (guild_id) VALUES (0) RETURNING *")
+            await db("INSERT INTO guild_settings (guild_id) VALUES (0)")
+            default_guild_settings = await db("SELECT * FROM guild_settings WHERE guild_id=0")
         for i, o in default_guild_settings[0].items():
             self.DEFAULT_GUILD_SETTINGS.setdefault(i, o)
 
@@ -327,7 +337,8 @@ class Bot(MinimalBot):
         # Get default user settings
         default_user_settings = await db("SELECT * FROM user_settings WHERE user_id=0")
         if not default_user_settings:
-            default_user_settings = await db("INSERT INTO user_settings (user_id) VALUES (0) RETURNING *")
+            await db("INSERT INTO user_settings (user_id) VALUES (0)")
+            default_user_settings = await db("SELECT * FROM user_settings WHERE user_id=0")
         for i, o in default_user_settings[0].items():
             self.DEFAULT_USER_SETTINGS.setdefault(i, o)
 
